# KrossTrading
---
[![Build Status](https://circleci.com/gh/krosstrading/ktrade.svg?style=shield)](https://circleci.com/gh/krosstrading/ktrade)
[![codecov](https://codecov.io/gh/krosstrading/ktrade/branch/main/graph/badge.svg)](https://codecov.io/gh/krosstrading/ktrade)

**Website:** https://www.krosstrading.com
**Documentation:**
**Bug reports:** https://github.com/krosstrading/krosstrading/issues
